<?php

return [
    [
        'property' => 'og:url',
        'content' =>  '{{url.home}}',
    ],
    [
        'property' => 'og:title',
        'content' => 'Help Center - {{site_name}}',
    ],
    [
        'property' => 'og:description',
        'content' => "Articles, Tutorials, FAQ's and more.",
    ],
    [
        'property' => 'og:type',
        'content' => 'website',
    ],
];
